@@ -27,6 +27,10 @@ public class Catalog {
       new Aggregators.ST_Envelope_Aggr(),
       new Aggregators.ST_Intersection_Aggr(),
       new Aggregators.ST_Union_Aggr(),
+      // Aliases for *_Aggr functions with *_Agg suffix
+      new Aggregators.ST_Envelope_Agg(),
+      new Aggregators.ST_Intersection_Agg(),
+      new Aggregators.ST_Union_Agg(),
       new Constructors.ST_Point(),
       new Constructors.ST_PointZ(),
       new Constructors.ST_PointM(),
@@ -73,6 +77,7 @@ public class Catalog {
       new Functions.ST_CrossesDateLine(),
       new Functions.ST_Expand(),
       new Functions.ST_Envelope(),
+      new Functions.ST_OrientedEnvelope(),
       new Functions.ST_Difference(),
       new Functions.ST_Dimension(),
       new Functions.ST_Distance(),
@@ -213,11 +218,13 @@ public class Catalog {
       new Functions.ST_Affine(),
       new Functions.ST_BoundingDiagonal(),
       new Functions.ST_Angle(),
+      new Functions.ST_ApproximateMedialAxis(),
       new Functions.ST_Degrees(),
       new Functions.ST_HausdorffDistance(),
       new Functions.ST_IsCollection(),
       new Functions.ST_CoordDim(),
-      new Functions.ST_IsValidReason()
+      new Functions.ST_IsValidReason(),
+      new Functions.ST_StraightSkeleton()
     };
   }
 
