@@ -25,6 +25,7 @@ import org.apache.sedona.common.enums.FileDataSplitter;
 import org.apache.sedona.common.enums.GeometryType;
 import org.apache.sedona.common.utils.FormatUtils;
 import org.apache.sedona.common.utils.GeoHashDecoder;
+import org.apache.sedona.flink.GeometryTypeSerializer;
 import org.locationtech.jts.geom.*;
 import org.locationtech.jts.io.ParseException;
 import org.locationtech.jts.io.gml2.GMLReader;
@@ -43,7 +44,10 @@ public class Constructors {
   }
 
   public static class ST_Point extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Double") Double x, @DataTypeHint("Double") Double y)
         throws ParseException {
       return org.apache.sedona.common.Constructors.point(x, y);
@@ -51,7 +55,10 @@ public class Constructors {
   }
 
   public static class ST_PointZ extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -60,7 +67,10 @@ public class Constructors {
       return eval(x, y, z, 0);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -72,7 +82,10 @@ public class Constructors {
   }
 
   public static class ST_PointM extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -81,7 +94,10 @@ public class Constructors {
       return eval(x, y, m, 0);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -93,7 +109,10 @@ public class Constructors {
   }
 
   public static class ST_PointZM extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -103,7 +122,10 @@ public class Constructors {
       return eval(x, y, z, m, 0);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -116,21 +138,30 @@ public class Constructors {
   }
 
   public static class ST_PointFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String s, @DataTypeHint("String") String inputDelimiter)
         throws ParseException {
       return getGeometryByType(s, inputDelimiter, GeometryType.POINT);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String s) throws ParseException {
       return eval(s, null);
     }
   }
 
   public static class ST_MakePointM extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -141,13 +172,19 @@ public class Constructors {
   }
 
   public static class ST_MakePoint extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Double") Double x, @DataTypeHint("Double") Double y)
         throws ParseException {
       return org.apache.sedona.common.Constructors.makePoint(x, y, null, null);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -156,7 +193,10 @@ public class Constructors {
       return org.apache.sedona.common.Constructors.makePoint(x, y, z, null);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double x,
         @DataTypeHint("Double") Double y,
@@ -168,7 +208,10 @@ public class Constructors {
   }
 
   public static class ST_LineFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String lineString, @DataTypeHint("String") String inputDelimiter)
         throws ParseException {
@@ -176,14 +219,20 @@ public class Constructors {
       return getGeometryByType(lineString, inputDelimiter, GeometryType.LINESTRING);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String lineString) throws ParseException {
       return eval(lineString, null);
     }
   }
 
   public static class ST_LineStringFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String lineString, @DataTypeHint("String") String inputDelimiter)
         throws ParseException {
@@ -191,14 +240,20 @@ public class Constructors {
       return new ST_LineFromText().eval(lineString, inputDelimiter);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String lineString) throws ParseException {
       return eval(lineString, null);
     }
   }
 
   public static class ST_PolygonFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String polygonString, @DataTypeHint("String") String inputDelimiter)
         throws ParseException {
@@ -206,14 +261,20 @@ public class Constructors {
       return getGeometryByType(polygonString, inputDelimiter, GeometryType.POLYGON);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String polygonString) throws ParseException {
       return eval(polygonString, null);
     }
   }
 
   public static class ST_MakeEnvelope extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double minX,
         @DataTypeHint("Double") Double minY,
@@ -223,7 +284,10 @@ public class Constructors {
       return org.apache.sedona.common.Constructors.makeEnvelope(minX, minY, maxX, maxY, srid);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double minX,
         @DataTypeHint("Double") Double minY,
@@ -234,7 +298,10 @@ public class Constructors {
   }
 
   public static class ST_PolygonFromEnvelope extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("Double") Double minX,
         @DataTypeHint("Double") Double minY,
@@ -258,12 +325,18 @@ public class Constructors {
   }
 
   public static class ST_GeomFromWKT extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wktString) throws ParseException {
       return org.apache.sedona.common.Constructors.geomFromWKT(wktString, 0);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String wktString, @DataTypeHint("Int") Integer srid)
         throws ParseException {
@@ -272,19 +345,28 @@ public class Constructors {
   }
 
   public static class ST_GeomFromEWKT extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wktString) throws ParseException {
       return org.apache.sedona.common.Constructors.geomFromEWKT(wktString);
     }
   }
 
   public static class ST_GeometryFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wktString) throws ParseException {
       return org.apache.sedona.common.Constructors.geomFromWKT(wktString, 0);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String wktString, @DataTypeHint("Int") Integer srid)
         throws ParseException {
@@ -293,12 +375,18 @@ public class Constructors {
   }
 
   public static class ST_GeomFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wktString) throws ParseException {
       return org.apache.sedona.common.Constructors.geomFromWKT(wktString, 0);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String wktString, @DataTypeHint("Int") Integer srid)
         throws ParseException {
@@ -307,31 +395,46 @@ public class Constructors {
   }
 
   public static class ST_GeomFromWKB extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString) throws ParseException {
       return getGeometryByFileData(wkbString, FileDataSplitter.WKB);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb) throws ParseException {
       return org.apache.sedona.common.Constructors.geomFromWKB(wkb);
     }
   }
 
   public static class ST_GeomFromEWKB extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString) throws ParseException {
       return getGeometryByFileData(wkbString, FileDataSplitter.WKB);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb) throws ParseException {
       return org.apache.sedona.common.Constructors.geomFromWKB(wkb);
     }
   }
 
   public static class ST_PointFromWKB extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString) throws ParseException {
       Geometry geometry = getGeometryByFileData(wkbString, FileDataSplitter.WKB);
       if (geometry instanceof Point) {
@@ -340,7 +443,10 @@ public class Constructors {
       return null; // Return null if geometry is not a Point
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString, int srid) throws ParseException {
       Geometry geometry = getGeometryByFileData(wkbString, FileDataSplitter.WKB);
       if (geometry instanceof Point) {
@@ -350,19 +456,28 @@ public class Constructors {
       return null; // Return null if geometry is not a Point
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb) throws ParseException {
       return org.apache.sedona.common.Constructors.pointFromWKB(wkb);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb, int srid) throws ParseException {
       return org.apache.sedona.common.Constructors.pointFromWKB(wkb, srid);
     }
   }
 
   public static class ST_LineFromWKB extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString) throws ParseException {
       Geometry geometry = getGeometryByFileData(wkbString, FileDataSplitter.WKB);
       if (geometry instanceof LineString) {
@@ -371,7 +486,10 @@ public class Constructors {
       return null; // Return null if geometry is not a Point
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString, int srid) throws ParseException {
       Geometry geometry = getGeometryByFileData(wkbString, FileDataSplitter.WKB);
       if (geometry instanceof LineString) {
@@ -381,19 +499,28 @@ public class Constructors {
       return null; // Return null if geometry is not a Linestring
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb) throws ParseException {
       return org.apache.sedona.common.Constructors.lineFromWKB(wkb);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb, int srid) throws ParseException {
       return org.apache.sedona.common.Constructors.lineFromWKB(wkb, srid);
     }
   }
 
   public static class ST_LinestringFromWKB extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString) throws ParseException {
       Geometry geometry = getGeometryByFileData(wkbString, FileDataSplitter.WKB);
       if (geometry instanceof LineString) {
@@ -402,7 +529,10 @@ public class Constructors {
       return null; // Return null if geometry is not a Linestring
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String wkbString, int srid) throws ParseException {
       Geometry geometry = getGeometryByFileData(wkbString, FileDataSplitter.WKB);
       if (geometry instanceof LineString) {
@@ -412,26 +542,38 @@ public class Constructors {
       return null; // Return null if geometry is not a Linestring
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb) throws ParseException {
       return org.apache.sedona.common.Constructors.lineFromWKB(wkb);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("Bytes") byte[] wkb, int srid) throws ParseException {
       return org.apache.sedona.common.Constructors.lineFromWKB(wkb, srid);
     }
   }
 
   public static class ST_GeomFromGeoJSON extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String geoJson) throws ParseException {
       return getGeometryByFileData(geoJson, FileDataSplitter.GEOJSON);
     }
   }
 
   public static class ST_GeomFromGeoHash extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String value, @DataTypeHint("Int") Integer precision)
         throws ParseException, GeoHashDecoder.InvalidGeoHashException {
@@ -439,7 +581,10 @@ public class Constructors {
       return GeoHashDecoder.decode(value, precision);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String value)
         throws ParseException, GeoHashDecoder.InvalidGeoHashException {
       return eval(value, null);
@@ -447,21 +592,30 @@ public class Constructors {
   }
 
   public static class ST_PointFromGeoHash extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint("String") String value, @DataTypeHint("Int") Integer precision) {
       // The default precision is the geohash length. Otherwise, use the precision given by the user
       return org.apache.sedona.common.Constructors.pointFromGeoHash(value, precision);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String value) {
       return eval(value, null);
     }
   }
 
   public static class ST_GeomFromGML extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String gml) throws ParseException {
       GMLReader reader = new GMLReader();
       try {
@@ -473,63 +627,90 @@ public class Constructors {
   }
 
   public static class ST_GeomFromKML extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint("String") String kml) throws ParseException {
       return new KMLReader().read(kml);
     }
   }
 
   public static class ST_MPolyFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint(value = "String") String wkt, @DataTypeHint("Int") Integer srid)
         throws ParseException {
       return org.apache.sedona.common.Constructors.mPolyFromText(wkt, srid);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint(value = "String") String wkt) throws ParseException {
       return org.apache.sedona.common.Constructors.mPolyFromText(wkt, 0);
     }
   }
 
   public static class ST_MLineFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint(value = "String") String wkt, @DataTypeHint("Int") Integer srid)
         throws ParseException {
       return org.apache.sedona.common.Constructors.mLineFromText(wkt, srid);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint(value = "String") String wkt) throws ParseException {
       return org.apache.sedona.common.Constructors.mLineFromText(wkt, 0);
     }
   }
 
   public static class ST_MPointFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint(value = "String") String wkt, @DataTypeHint("Int") Integer srid)
         throws ParseException {
       return org.apache.sedona.common.Constructors.mPointFromText(wkt, srid);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint(value = "String") String wkt) throws ParseException {
       return org.apache.sedona.common.Constructors.mPointFromText(wkt, 0);
     }
   }
 
   public static class ST_GeomCollFromText extends ScalarFunction {
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(
         @DataTypeHint(value = "String") String wkt, @DataTypeHint("Int") Integer srid)
         throws ParseException {
       return org.apache.sedona.common.Constructors.geomCollFromText(wkt, srid);
     }
 
-    @DataTypeHint(value = "RAW", bridgedTo = org.locationtech.jts.geom.Geometry.class)
+    @DataTypeHint(
+        value = "RAW",
+        rawSerializer = GeometryTypeSerializer.class,
+        bridgedTo = Geometry.class)
     public Geometry eval(@DataTypeHint(value = "String") String wkt) throws ParseException {
       return org.apache.sedona.common.Constructors.geomCollFromText(wkt, 0);
     }
