@@ -60,99 +60,6 @@ from pyspark.pandas.internal import (
 # IMPLEMENTATION STATUS TRACKING
 # ============================================================================
 
-IMPLEMENTATION_STATUS = {
-    "IMPLEMENTED": [
-        "area",
-        "buffer",
-        "bounds",
-        "centroid",
-        "contains",
-        "crs",
-        "distance",
-        "envelope",
-        "geometry",
-        "intersection",
-        "intersects",
-        "is_empty",
-        "is_simple",
-        "is_valid",
-        "is_valid_reason",
-        "length",
-        "make_valid",
-        "set_crs",
-        "to_crs",
-        "to_geopandas",
-        "to_wkb",
-        "to_wkt",
-        "x",
-        "y",
-        "z",
-        "has_z",
-        "get_geometry",
-        "boundary",
-        "total_bounds",
-        "estimate_utm_crs",
-        "isna",
-        "isnull",
-        "notna",
-        "notnull",
-        "from_xy",
-        "copy",
-        "geom_type",
-        "sindex",
-    ],
-    "NOT_IMPLEMENTED": [
-        "clip",
-        "contains_properly",
-        "convex_hull",
-        "count_coordinates",
-        "count_geometries",
-        "count_interior_rings",
-        "explode",
-        "force_2d",
-        "force_3d",
-        "from_file",
-        "from_shapely",
-        "from_arrow",
-        "line_merge",
-        "reverse",
-        "segmentize",
-        "to_json",
-        "to_arrow",
-        "to_file",
-        "transform",
-        "unary_union",
-        "union_all",
-        "intersection_all",
-        "type",
-        "is_ring",
-        "is_ccw",
-        "is_closed",
-        "get_precision",
-        "concave_hull",
-        "delaunay_triangles",
-        "voronoi_polygons",
-        "minimum_rotated_rectangle",
-        "exterior",
-        "extract_unique_points",
-        "offset_curve",
-        "interiors",
-        "remove_repeated_points",
-        "set_precision",
-        "representative_point",
-        "minimum_bounding_circle",
-        "minimum_bounding_radius",
-        "minimum_clearance",
-        "normalize",
-        "m",
-    ],
-    "PARTIALLY_IMPLEMENTED": [
-        "fillna",  # Limited parameter support (no 'limit' parameter)
-        "from_wkb",
-        "from_wkt",  # Limited error handling options (only 'raise' supported)
-    ],
-}
-
 IMPLEMENTATION_PRIORITY = {
     "HIGH": [
         "contains",
@@ -280,7 +187,7 @@ class GeoSeries(GeoFrame, pspd.Series):
     - Uses Spark for distributed processing
     - Geometries are stored in WKB (Well-Known Binary) format internally
     - Some methods may have different performance characteristics
-    - Not all GeoPandas methods are implemented yet (see IMPLEMENTATION_STATUS)
+    - Not all GeoPandas methods are implemented yet (see Sedona GeoPandas docs).
 
     Performance Considerations:
     - Operations are distributed across Spark cluster
@@ -310,14 +217,22 @@ class GeoSeries(GeoFrame, pspd.Series):
         """
         Initialize a GeoSeries object.
 
-        Parameters:
-        - data: The input data for the GeoSeries. It can be a GeoDataFrame, GeoSeries, or pandas Series.
-        - index: The index for the GeoSeries.
-        - crs: Coordinate Reference System for the GeoSeries.
-        - dtype: Data type for the GeoSeries.
-        - name: Name of the GeoSeries.
-        - copy: Whether to copy the input data.
-        - fastpath: Internal parameter for fast initialization.
+        Parameters
+        ----------
+        data : array-like, GeoDataFrame, GeoSeries, or pandas Series
+            The input data for the GeoSeries.
+        index : array-like, optional
+            The index for the GeoSeries.
+        crs : pyproj.CRS, optional
+            Coordinate Reference System for the GeoSeries.
+        dtype : dtype, optional
+            Data type for the GeoSeries.
+        name : str, optional
+            Name of the GeoSeries.
+        copy : bool, default False
+            Whether to copy the input data.
+        fastpath : bool, default False
+            Internal parameter for fast initialization.
 
         Examples
         --------
@@ -364,8 +279,8 @@ class GeoSeries(GeoFrame, pspd.Series):
             assert not copy
             assert not fastpath
 
-            # We don't check crs validity to keep the operation lazy.
-            # Keep the original code for now
+            # We don't check CRS validity to keep the operation lazy.
+            # Keep the original code for now.
             # data_crs = None
             # if hasattr(data, "crs"):
             #     data_crs = data.crs
@@ -377,7 +292,7 @@ class GeoSeries(GeoFrame, pspd.Series):
             #         "'GeoSeries.to_crs(crs)' to reproject geometries. "
             #     )
 
-            # PySpark Pandas' ps.Series.__init__() does not construction from a
+            # PySpark Pandas' ps.Series.__init__() does not support construction from a
             # ps.Series input. For now, we manually implement the logic.
 
             index = data._col_label if index is None else index
@@ -411,10 +326,10 @@ class GeoSeries(GeoFrame, pspd.Series):
 
             pd_series = pd_series.astype(object)
 
-            # initialize the parent class pyspark Series with the pandas Series
+            # Initialize the parent class PySpark Series with the pandas Series.
             super().__init__(data=pd_series)
 
-        # Ensure we're storing geometry types
+        # Ensure we're storing geometry types.
         if (
             self.spark.data_type != GeometryType()
             and self.spark.data_type != NullType()
@@ -471,23 +386,23 @@ class GeoSeries(GeoFrame, pspd.Series):
         if len(self) == 0:
             return None
 
-        # F.first is non-deterministic, but it doesn't matter because all non-null values should be the same
+        # F.first is non-deterministic, but it doesn't matter because all non-null values should be the same.
         spark_col = stf.ST_SRID(F.first(self.spark.column, ignorenulls=True))
 
-        # Set this to avoid error complaining that we don't have a groupby column
+        # Set this to avoid error complaining that we don't have a groupby column.
         tmp_series = self._query_geometry_column(
             spark_col,
             returns_geom=False,
             is_aggr=True,
         )
 
-        # All geometries should have the same srid
-        # so we just take the srid of the first non-null element
+        # All geometries should have the same SRID,
+        # so we just take the SRID of the first non-null element.
         srid = tmp_series.item()
-        # Turn np.nan to 0 to avoid error
+        # Turn np.nan to 0 to avoid error.
         srid = 0 if np.isnan(srid) else srid
 
-        # Sedona returns 0 if doesn't exist
+        # Sedona returns 0 if SRID doesn't exist.
         return CRS.from_user_input(srid) if srid != 0 else None
 
     @crs.setter
@@ -603,8 +518,8 @@ class GeoSeries(GeoFrame, pspd.Series):
         elif epsg is not None:
             crs = CRS.from_epsg(epsg)
 
-        # The below block for the not allow_override case is eager due to the self.crs call
-        # This hurts performance and user experience, hence the default being set to True in Sedona
+        # The below block for the not allow_override case is eager due to the self.crs call.
+        # This hurts performance and user experience, hence the default being set to True in Sedona.
         if not allow_override:
             curr_crs = self.crs
 
@@ -616,7 +531,7 @@ class GeoSeries(GeoFrame, pspd.Series):
                     "transform the geometries, use 'GeoSeries.to_crs' instead."
                 )
 
-        # 0 indicates no srid in sedona
+        # 0 indicates no SRID in Sedona.
         new_epsg = crs.to_epsg() if crs else 0
 
         spark_col = stf.ST_SetSRID(self.spark.column, new_epsg)
@@ -674,8 +589,8 @@ class GeoSeries(GeoFrame, pspd.Series):
         index_spark_columns = []
         index_fields = []
         if not is_aggr:
-            # We always select NATURAL_ORDER_COLUMN_NAME, to avoid having to regenerate it in the result
-            # We always select SPARK_DEFAULT_INDEX_NAME, to retain series index info
+            # We always select NATURAL_ORDER_COLUMN_NAME, to avoid having to regenerate it in the result.
+            # We always select SPARK_DEFAULT_INDEX_NAME, to retain series index info.
 
             exprs.append(scol_for(df, SPARK_DEFAULT_INDEX_NAME))
             exprs.append(scol_for(df, NATURAL_ORDER_COLUMN_NAME))
@@ -687,7 +602,7 @@ class GeoSeries(GeoFrame, pspd.Series):
                 scol_for(df, SPARK_DEFAULT_INDEX_NAME),
                 scol_for(df, NATURAL_ORDER_COLUMN_NAME),
             )
-        # else if is_aggr, we don't select the index columns
+        # Otherwise, if is_aggr, we don't select the index columns.
         else:
             sdf = df.select(*exprs)
 
@@ -701,7 +616,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
         ps_series = first_series(PandasOnSparkDataFrame(internal))
 
-        # Convert spark series default name to pandas series default name (None) if needed
+        # Convert Spark series default name to pandas series default name (None) if needed.
         series_name = None if rename == SPARK_DEFAULT_SERIES_NAME else rename
         ps_series = ps_series.rename(series_name)
 
@@ -714,16 +629,18 @@ class GeoSeries(GeoFrame, pspd.Series):
 
     def to_geopandas(self) -> gpd.GeoSeries:
         """
-        Convert the GeoSeries to a geopandas GeoSeries.
+        Convert the GeoSeries to a GeoPandas GeoSeries.
 
-        Returns:
-        - geopandas.GeoSeries: A geopandas GeoSeries.
+        Returns
+        -------
+        geopandas.GeoSeries
+            A GeoPandas GeoSeries.
         """
         from pyspark.pandas.utils import log_advice
 
         log_advice(
             "`to_geopandas` loads all data into the driver's memory. "
-            "It should only be used if the resulting geopandas GeoSeries is expected to be small."
+            "It should only be used if the resulting GeoPandas GeoSeries is expected to be small."
         )
         return self._to_geopandas()
 
@@ -801,28 +718,20 @@ class GeoSeries(GeoFrame, pspd.Series):
 
     @property
     def geom_type(self) -> pspd.Series:
-        spark_col = stf.GeometryType(self.spark.column)
+        spark_col = stf.ST_GeometryType(self.spark.column)
         result = self._query_geometry_column(
             spark_col,
             returns_geom=False,
         )
 
-        # Sedona returns the string in all caps unlike Geopandas
-        sgpd_to_gpg_name_map = {
-            "POINT": "Point",
-            "LINESTRING": "LineString",
-            "POLYGON": "Polygon",
-            "MULTIPOINT": "MultiPoint",
-            "MULTILINESTRING": "MultiLineString",
-            "MULTIPOLYGON": "MultiPolygon",
-            "GEOMETRYCOLLECTION": "GeometryCollection",
-        }
-        result = result.map(lambda x: sgpd_to_gpg_name_map.get(x, x))
+        # ST_GeometryType returns string as 'ST_Point'
+        # we crop the prefix off to get 'Point'
+        result = result.map(lambda x: x[3:])
         return result
 
     @property
     def type(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError(
             _not_implemented_error("type", "Returns numeric geometry type codes.")
         )
@@ -831,21 +740,25 @@ class GeoSeries(GeoFrame, pspd.Series):
     def length(self) -> pspd.Series:
         spark_expr = (
             F.when(
-                stf.GeometryType(self.spark.column).isin(
-                    ["LINESTRING", "MULTILINESTRING"]
+                stf.ST_GeometryType(self.spark.column).isin(
+                    ["ST_LineString", "ST_MultiLineString"]
                 ),
                 stf.ST_Length(self.spark.column),
             )
             .when(
-                stf.GeometryType(self.spark.column).isin(["POLYGON", "MULTIPOLYGON"]),
+                stf.ST_GeometryType(self.spark.column).isin(
+                    ["ST_Polygon", "ST_MultiPolygon"]
+                ),
                 stf.ST_Perimeter(self.spark.column),
             )
             .when(
-                stf.GeometryType(self.spark.column).isin(["POINT", "MULTIPOINT"]),
+                stf.ST_GeometryType(self.spark.column).isin(
+                    ["ST_Point", "ST_MultiPoint"]
+                ),
                 0.0,
             )
             .when(
-                stf.GeometryType(self.spark.column).isin(["GEOMETRYCOLLECTION"]),
+                stf.ST_GeometryType(self.spark.column).isin(["ST_GeometryCollection"]),
                 stf.ST_Length(self.spark.column) + stf.ST_Perimeter(self.spark.column),
             )
         )
@@ -880,7 +793,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         return _to_bool(result)
 
     def count_coordinates(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError(
             _not_implemented_error(
                 "count_coordinates",
@@ -889,7 +802,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
 
     def count_geometries(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError(
             _not_implemented_error(
                 "count_geometries",
@@ -898,7 +811,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
 
     def count_interior_rings(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError(
             _not_implemented_error(
                 "count_interior_rings",
@@ -936,6 +849,30 @@ class GeoSeries(GeoFrame, pspd.Series):
             returns_geom=True,
         )
 
+    def symmetric_difference(self, other, align=None) -> "GeoSeries":
+        other_series, extended = self._make_series_of_val(other)
+        align = False if extended else align
+
+        spark_expr = stf.ST_SymDifference(F.col("L"), F.col("R"))
+        return self._row_wise_operation(
+            spark_expr,
+            other_series,
+            align=align,
+            returns_geom=True,
+        )
+
+    def union(self, other, align=None) -> "GeoSeries":
+        other_series, extended = self._make_series_of_val(other)
+        align = False if extended else align
+
+        spark_expr = stf.ST_Union(F.col("L"), F.col("R"))
+        return self._row_wise_operation(
+            spark_expr,
+            other_series,
+            align=align,
+            returns_geom=True,
+        )
+
     @property
     def is_simple(self) -> pspd.Series:
         spark_expr = stf.ST_IsSimple(self.spark.column)
@@ -956,7 +893,7 @@ class GeoSeries(GeoFrame, pspd.Series):
 
     @property
     def is_ccw(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError(
             _not_implemented_error(
                 "is_ccw",
@@ -966,13 +903,17 @@ class GeoSeries(GeoFrame, pspd.Series):
 
     @property
     def is_closed(self):
-        # Implementation of the abstract method
-        raise NotImplementedError(
-            _not_implemented_error(
-                "is_closed",
-                "Tests if LineString geometries are closed (start equals end point).",
-            )
+        # Only check LineStrings; return False for all other geometry types
+        spark_expr = F.when(
+            stf.ST_GeometryType(self.spark.column) == "ST_LineString",
+            stf.ST_IsClosed(self.spark.column),
+        ).otherwise(False)
+
+        result = self._query_geometry_column(
+            spark_expr,
+            returns_geom=False,
         )
+        return _to_bool(result)
 
     @property
     def has_z(self) -> pspd.Series:
@@ -983,11 +924,11 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
 
     def get_precision(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def get_geometry(self, index) -> "GeoSeries":
-        # Sedona errors on negative indexes, so we use a case statement to handle it ourselves
+        # Sedona errors on negative indexes, so we use a case statement to handle it ourselves.
         spark_expr = stf.ST_GeometryN(
             F.col("L"),
             F.when(
@@ -1016,7 +957,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         # Geopandas and shapely return NULL for GeometryCollections, so we handle it separately
         # https://shapely.readthedocs.io/en/stable/reference/shapely.boundary.html
         spark_expr = F.when(
-            stf.GeometryType(self.spark.column).isin(["GEOMETRYCOLLECTION"]),
+            stf.ST_GeometryType(self.spark.column).isin(["ST_GeometryCollection"]),
             None,
         ).otherwise(stf.ST_Boundary(self.spark.column))
         return self._query_geometry_column(
@@ -1032,24 +973,23 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
 
     def concave_hull(self, ratio=0.0, allow_holes=False):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     @property
-    def convex_hull(self):
-        # Implementation of the abstract method
-        raise NotImplementedError(
-            _not_implemented_error(
-                "convex_hull", "Computes the convex hull of each geometry."
-            )
+    def convex_hull(self) -> "GeoSeries":
+        spark_expr = stf.ST_ConvexHull(self.spark.column)
+        return self._query_geometry_column(
+            spark_expr,
+            returns_geom=True,
         )
 
     def delaunay_triangles(self, tolerance=0.0, only_edges=False):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def voronoi_polygons(self, tolerance=0.0, extend_to=None, only_edges=False):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     @property
@@ -1061,53 +1001,60 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
 
     def minimum_rotated_rectangle(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     @property
     def exterior(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def extract_unique_points(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def offset_curve(self, distance, quad_segs=8, join_style="round", mitre_limit=5.0):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     @property
     def interiors(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def remove_repeated_points(self, tolerance=0.0):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def set_precision(self, grid_size, mode="valid_output"):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def representative_point(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
-    def minimum_bounding_circle(self):
-        # Implementation of the abstract method
-        raise NotImplementedError("This method is not implemented yet.")
+    def minimum_bounding_circle(self) -> "GeoSeries":
+        spark_expr = stf.ST_MinimumBoundingCircle(self.spark.column)
+        return self._query_geometry_column(
+            spark_expr,
+            returns_geom=True,
+        )
 
-    def minimum_bounding_radius(self):
-        # Implementation of the abstract method
-        raise NotImplementedError("This method is not implemented yet.")
+    def minimum_bounding_radius(self) -> pspd.Series:
+        spark_struct = stf.ST_MinimumBoundingRadius(self.spark.column)
+        spark_radius = spark_struct.getField("radius")
+        return self._query_geometry_column(
+            spark_radius,
+            returns_geom=False,
+        )
 
     def minimum_clearance(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def normalize(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def make_valid(self, *, method="linework", keep_collapsed=True) -> "GeoSeries":
@@ -1123,12 +1070,12 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
 
     def reverse(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def segmentize(self, max_segment_length):
         other_series, extended = self._make_series_of_val(max_segment_length)
-        align = False if extended else align
+        align = not extended
 
         spark_expr = stf.ST_Segmentize(F.col("L"), F.col("R"))
         return self._row_wise_operation(
@@ -1139,19 +1086,27 @@ class GeoSeries(GeoFrame, pspd.Series):
         )
 
     def transform(self, transformation, include_z=False):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
-    def force_2d(self):
-        # Implementation of the abstract method
-        raise NotImplementedError("This method is not implemented yet.")
+    def force_2d(self) -> "GeoSeries":
+        spark_expr = stf.ST_Force_2D(self.spark.column)
+        return self._query_geometry_column(spark_expr, returns_geom=True)
 
-    def force_3d(self, z=0):
-        # Implementation of the abstract method
-        raise NotImplementedError("This method is not implemented yet.")
+    def force_3d(self, z=0.0) -> "GeoSeries":
+        other_series, extended = self._make_series_of_val(z)
+        align = not extended
+
+        spark_expr = stf.ST_Force3D(F.col("L"), F.col("R"))
+        return self._row_wise_operation(
+            spark_expr,
+            other_series,
+            align=align,
+            returns_geom=True,
+        )
 
     def line_merge(self, directed=False):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     # ============================================================================
@@ -1160,7 +1115,7 @@ class GeoSeries(GeoFrame, pspd.Series):
 
     @property
     def unary_union(self):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def union_all(self, method="unary", grid_size=None) -> BaseGeometry:
@@ -1174,7 +1129,7 @@ class GeoSeries(GeoFrame, pspd.Series):
             )
 
         if len(self) == 0:
-            # While it's not explicitly defined in geopandas docs, this is what geopandas returns for empty GeoSeries
+            # While it's not explicitly defined in GeoPandas docs, this is what GeoPandas returns for empty GeoSeries.
             # If it ever changes for some reason, we'll catch that with the test
             from shapely.geometry import GeometryCollection
 
@@ -1187,14 +1142,26 @@ class GeoSeries(GeoFrame, pspd.Series):
         geom = ps_series.iloc[0]
         return geom
 
+    def intersection_all(self) -> BaseGeometry:
+        if len(self) == 0:
+            from shapely.geometry import GeometryCollection
+
+            return GeometryCollection()
+        spark_expr = sta.ST_Intersection_Aggr(self.spark.column)
+        tmp = self._query_geometry_column(spark_expr, returns_geom=False, is_aggr=True)
+
+        ps_series = tmp.take([0])
+        geom = ps_series.iloc[0]
+        return geom
+
     def crosses(self, other, align=None) -> pspd.Series:
-        # Sedona does not support GeometryCollection (errors), so we return NULL for now to avoid error
+        # Sedona does not support GeometryCollection (errors), so we return NULL for now to avoid error.
         other_series, extended = self._make_series_of_val(other)
         align = False if extended else align
 
         spark_expr = F.when(
-            (stf.GeometryType(F.col("L")) == "GEOMETRYCOLLECTION")
-            | (stf.GeometryType(F.col("R")) == "GEOMETRYCOLLECTION"),
+            (stf.ST_GeometryType(F.col("L")) == "ST_GeometryCollection")
+            | (stf.ST_GeometryType(F.col("R")) == "ST_GeometryCollection"),
             None,
         ).otherwise(stp.ST_Crosses(F.col("L"), F.col("R")))
         result = self._row_wise_operation(
@@ -1207,7 +1174,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         return _to_bool(result)
 
     def disjoint(self, other, align=None):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError("This method is not implemented yet.")
 
     def intersects(
@@ -1226,7 +1193,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         return _to_bool(result)
 
     def overlaps(self, other, align=None) -> pspd.Series:
-        # Note: We cannot efficiently match geopandas behavior because Sedona's ST_Overlaps returns True for equal geometries
+        # Note: We cannot efficiently match GeoPandas behavior because Sedona's ST_Overlaps returns True for equal geometries.
         # ST_Overlaps(`L`, `R`) AND ST_Equals(`L`, `R`) does not work because ST_Equals errors on invalid geometries
 
         other_series, extended = self._make_series_of_val(other)
@@ -1371,13 +1338,13 @@ class GeoSeries(GeoFrame, pspd.Series):
         """
         from pyspark.sql.functions import col
 
-        # Note: this is specifically False. None is valid since it defaults to True similar to geopandas
+        # Note: this is specifically False. None is valid since it defaults to True similar to GeoPandas.
         index_col = (
             NATURAL_ORDER_COLUMN_NAME if align is False else SPARK_DEFAULT_INDEX_NAME
         )
 
         # This code assumes there is only one index (SPARK_DEFAULT_INDEX_NAME)
-        # and would need to be updated if Sedona later supports multi-index
+        # and would need to be updated if Sedona later supports multi-index.
 
         sdf = self._internal.spark_frame
         other_sdf = other._internal.spark_frame
@@ -1424,9 +1391,22 @@ class GeoSeries(GeoFrame, pspd.Series):
             keep_name=keep_name,
         )
 
-    def intersection_all(self):
-        # Implementation of the abstract method
-        raise NotImplementedError("This method is not implemented yet.")
+    # ============================================================================
+    # Binary Predicates
+    # ============================================================================
+    def relate(self, other, align=None) -> pspd.Series:
+        other, extended = self._make_series_of_val(other)
+        align = False if extended else align
+
+        spark_col = stp.ST_Relate(F.col("L"), F.col("R"))
+        result = self._row_wise_operation(
+            spark_col,
+            other,
+            align,
+            returns_geom=False,
+            default_val=None,
+        )
+        return result
 
     # ============================================================================
     # SPATIAL PREDICATES
@@ -1447,7 +1427,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         return _to_bool(result)
 
     def contains_properly(self, other, align=None):
-        # Implementation of the abstract method
+        # Implementation of the abstract method.
         raise NotImplementedError(
             _not_implemented_error(
                 "contains_properly",
@@ -1466,7 +1446,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         **kwargs,
     ) -> "GeoSeries":
         if single_sided:
-            # Reverse the following logic in common/src/main/java/org/apache/sedona/common/Functions.java buffer() to avoid negating the distance
+            # Reverse the following logic in common/src/main/java/org/apache/sedona/common/Functions.java buffer() to avoid negating the distance.
             #   if (bufferParameters.isSingleSided()
             #       && (params.toLowerCase().contains("left") && radius < 0
             #           || params.toLowerCase().contains("right") && radius > 0)) {
@@ -2013,7 +1993,6 @@ class GeoSeries(GeoFrame, pspd.Series):
 
         from pyspark.pandas.utils import default_session
         from pyspark.pandas.internal import InternalField
-        import numpy as np
 
         if isinstance(data, list) and not isinstance(data[0], (tuple, list)):
             data = [(obj,) for obj in data]
@@ -2130,7 +2109,7 @@ class GeoSeries(GeoFrame, pspd.Series):
         GeoSeries.isna : inverse of notna
         GeoSeries.is_empty : detect empty geometries
         """
-        # After Sedona's minimum spark version is 3.5.0, we can use F.isnotnull(self.spark.column) instead
+        # After Sedona's minimum Spark version is 3.5.0, we can use F.isnotnull(self.spark.column) instead.
         spark_expr = ~F.isnull(self.spark.column)
         result = self._query_geometry_column(
             spark_expr,
@@ -2394,13 +2373,17 @@ class GeoSeries(GeoFrame, pspd.Series):
             ],
             column_label_names=None,
         )
-        return pspd.DataFrame(internal)
+        result = pspd.DataFrame(internal)
+        # Convert max/min float values to NaN
+        # e.g POINT EMPTY, represented as POINT (NaN NaN), should result in all NaN
+        result = result.replace(np.finfo(np.float64).max, np.nan).replace(
+            -np.finfo(np.float64).max, np.nan
+        )
+        return result
 
     @property
     def total_bounds(self):
-        import numpy as np
         import warnings
-        from pyspark.sql import functions as F
 
         if len(self) == 0:
             # numpy 'min' cannot handle empty arrays
@@ -2412,23 +2395,18 @@ class GeoSeries(GeoFrame, pspd.Series):
             warnings.filterwarnings(
                 "ignore", r"All-NaN slice encountered", RuntimeWarning
             )
-            total_bounds_df = ps_df.agg(
-                {
-                    "minx": ["min"],
-                    "miny": ["min"],
-                    "maxx": ["max"],
-                    "maxy": ["max"],
-                }
-            )
 
-            return np.array(
-                (
-                    np.nanmin(total_bounds_df["minx"]["min"]),  # minx
-                    np.nanmin(total_bounds_df["miny"]["min"]),  # miny
-                    np.nanmax(total_bounds_df["maxx"]["max"]),  # maxx
-                    np.nanmax(total_bounds_df["maxy"]["max"]),  # maxy
-                )
-            )
+            minx = ps_df["minx"].min(skipna=True)
+            miny = ps_df["miny"].min(skipna=True)
+
+            # skipna=True doesn't work properly for max(), so we use dropna() as a workaround
+            maxx = ps_df["maxx"].dropna()
+            maxy = ps_df["maxy"].dropna()
+
+            maxx = maxx.max(skipna=True) if not maxx.empty else np.nan
+            maxy = maxy.max(skipna=True) if not maxy.empty else np.nan
+
+            return np.array((minx, miny, maxx, maxy))
 
     # GeoSeries-only (not in GeoDataFrame)
     def estimate_utm_crs(self, datum_name: str = "WGS 84") -> "CRS":
@@ -2471,10 +2449,10 @@ class GeoSeries(GeoFrame, pspd.Series):
         from pyproj.aoi import AreaOfInterest
         from pyproj.database import query_utm_crs_info
 
-        # This implementation replicates the implementation in geopandas's implementation exactly.
+        # This implementation replicates the implementation in GeoPandas's implementation exactly.
         # https://github.com/geopandas/geopandas/blob/main/geopandas/array.py
         # The only difference is that we use Sedona's total_bounds property which is more efficient and scalable
-        # than the geopandas implementation. The rest of the implementation always executes on 4 points (minx, miny, maxx, maxy),
+        # than the GeoPandas implementation. The rest of the implementation always executes on 4 points (minx, miny, maxx, maxy),
         # so the numpy and pyproj implementations are reasonable.
 
         if not self.crs:
@@ -2749,8 +2727,8 @@ e": "Feature", "properties": {}, "geometry": {"type": "Point", "coordinates": [3
         ]
 
         """
-        # Because this function returns the arrow array in memory, we simply rely on geopandas's implementation.
-        # This also returns a geopandas specific data type, which can be converted to an actual pyarrow array,
+        # Because this function returns the Arrow array in memory, we simply rely on GeoPandas's implementation.
+        # This also returns a GeoPandas-specific data type, which can be converted to an actual PyArrow array,
         # so there is no direct Sedona equivalent. This way we also get all of the arguments implemented for free.
         return self.to_geopandas().to_arrow(
             geometry_encoding=geometry_encoding,
@@ -2863,11 +2841,13 @@ e": "Feature", "properties": {}, "geometry": {"type": "Point", "coordinates": [3
         Returns:
             tuple[pspd.Series, bool]:
                 - The series of the value
-                - Whether returned value was a single object extended into a series (useful for row-wise 'align' parameter)
+                - Whether returned value was a extended into a series (useful for row-wise 'align' parameter)
         """
         # generator instead of a in-memory list
         if isinstance(value, GeoDataFrame):
             return value.geometry, False
+        elif isinstance(value, (list, np.ndarray)):
+            return pspd.Series(value), True
         elif not isinstance(value, pspd.Series):
             lst = [value for _ in range(len(self))]
             if isinstance(value, BaseGeometry):
