@@ -1,32 +1,33 @@
-#  Licensed to the Apache Software Foundation (ASF) under one
-#  or more contributor license agreements.  See the NOTICE file
-#  distributed with this work for additional information
-#  regarding copyright ownership.  The ASF licenses this file
-#  to you under the Apache License, Version 2.0 (the
-#  "License"); you may not use this file except in compliance
-#  with the License.  You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#  Unless required by applicable law or agreed to in writing,
-#  software distributed under the License is distributed on an
-#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-#  KIND, either express or implied.  See the License for the
-#  specific language governing permissions and limitations
-#  under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 import os
 
 from shapely.wkt import loads
-from tests.test_base import TestBase
-from tests.tools import tests_resource
 
-from sedona.core.enums import GridType, IndexType
-from sedona.core.formatMapper import WktReader
-from sedona.core.spatialOperator.join_params import JoinParams
-from sedona.core.spatialOperator.join_query_raw import JoinQueryRaw
-from sedona.core.spatialOperator.range_query_raw import RangeQueryRaw
-from sedona.core.SpatialRDD import CircleRDD
+from tests import tests_resource
+from tests.test_base import TestBase
+
+from sedona.spark.core.enums import GridType, IndexType
+from sedona.spark.core.formatMapper import WktReader
+from sedona.spark.core.spatialOperator.join_params import JoinParams
+from sedona.spark.core.spatialOperator.join_query_raw import JoinQueryRaw
+from sedona.spark.core.spatialOperator.range_query_raw import RangeQueryRaw
+from sedona.spark.core.SpatialRDD import CircleRDD
 
 bank_csv_path = os.path.join(tests_resource, "small/points.csv")
 areas_csv_path = os.path.join(tests_resource, "small/areas.csv")
