@@ -1,35 +1,34 @@
-#  Licensed to the Apache Software Foundation (ASF) under one
-#  or more contributor license agreements.  See the NOTICE file
-#  distributed with this work for additional information
-#  regarding copyright ownership.  The ASF licenses this file
-#  to you under the Apache License, Version 2.0 (the
-#  "License"); you may not use this file except in compliance
-#  with the License.  You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#  Unless required by applicable law or agreed to in writing,
-#  software distributed under the License is distributed on an
-#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-#  KIND, either express or implied.  See the License for the
-#  specific language governing permissions and limitations
-#  under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 import os
 import shutil
 
-import pytest
+from tests import tests_resource
 from tests.test_base import TestBase
-from tests.tools import tests_resource
 
-from sedona.core.enums import GridType, IndexType
-from sedona.core.formatMapper.disc_utils import (
+from sedona.spark.core.enums import GridType, IndexType
+from sedona.spark.core.formatMapper.disc_utils import (
     GeoType,
     load_spatial_index_rdd_from_disc,
     load_spatial_rdd_from_disc,
 )
-from sedona.core.spatialOperator import JoinQuery
-from sedona.core.SpatialRDD import LineStringRDD, PointRDD, PolygonRDD
+from sedona.spark.core.spatialOperator import JoinQuery
+from sedona.spark.core.SpatialRDD import LineStringRDD, PointRDD, PolygonRDD
 
 
 def remove_directory(path: str) -> bool:
