@@ -1,28 +1,27 @@
-#  Licensed to the Apache Software Foundation (ASF) under one
-#  or more contributor license agreements.  See the NOTICE file
-#  distributed with this work for additional information
-#  regarding copyright ownership.  The ASF licenses this file
-#  to you under the Apache License, Version 2.0 (the
-#  "License"); you may not use this file except in compliance
-#  with the License.  You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#  Unless required by applicable law or agreed to in writing,
-#  software distributed under the License is distributed on an
-#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-#  KIND, either express or implied.  See the License for the
-#  specific language governing permissions and limitations
-#  under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 import os
 
-import pyspark
+from tests import tests_resource
 from tests.test_base import TestBase
-from tests.tools import tests_resource
 
-from sedona.core.formatMapper.geo_json_reader import GeoJsonReader
-from sedona.core.jvm.config import SedonaMeta, is_greater_or_equal_version
+from sedona.spark.core.formatMapper.geo_json_reader import GeoJsonReader
+from sedona.spark.core.jvm.config import SedonaMeta, is_greater_or_equal_version
 
 geo_json_contains_id = os.path.join(tests_resource, "testContainsId.json")
 geo_json_geom_with_feature_property = os.path.join(tests_resource, "testPolygon.json")
