@@ -175,6 +175,18 @@ public class UDFs {
     return Functions.azimuth(GeometrySerde.deserialize(left), GeometrySerde.deserialize(right));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geometry"})
+  public static byte[] ST_ApproximateMedialAxis(byte[] geometry) {
+    return GeometrySerde.serialize(
+        Functions.approximateMedialAxis(GeometrySerde.deserialize(geometry)));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "maxVertices"})
+  public static byte[] ST_ApproximateMedialAxis(byte[] geometry, int maxVertices) {
+    return GeometrySerde.serialize(
+        Functions.approximateMedialAxis(GeometrySerde.deserialize(geometry), maxVertices));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geometry"})
   public static byte[] ST_Boundary(byte[] geometry) {
     return GeometrySerde.serialize(Functions.boundary(GeometrySerde.deserialize(geometry)));
@@ -361,6 +373,11 @@ public class UDFs {
     return GeometrySerde.serialize(Functions.envelope(GeometrySerde.deserialize(geometry)));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geometry"})
+  public static byte[] ST_OrientedEnvelope(byte[] geometry) {
+    return GeometrySerde.serialize(Functions.orientedEnvelope(GeometrySerde.deserialize(geometry)));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geometry", "uniformDelta"})
   public static byte[] ST_Expand(byte[] geometry, double uniformDelta) {
     return GeometrySerde.serialize(
@@ -1055,6 +1072,17 @@ public class UDFs {
     return GeometrySerde.serialize(Functions.startPoint(GeometrySerde.deserialize(geometry)));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geometry"})
+  public static byte[] ST_StraightSkeleton(byte[] geometry) {
+    return GeometrySerde.serialize(Functions.straightSkeleton(GeometrySerde.deserialize(geometry)));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "maxVertices"})
+  public static byte[] ST_StraightSkeleton(byte[] geometry, int maxVertices) {
+    return GeometrySerde.serialize(
+        Functions.straightSkeleton(GeometrySerde.deserialize(geometry), maxVertices));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"input", "reference", "tolerance"})
   public static byte[] ST_Snap(byte[] input, byte[] reference, double tolerance) {
     return GeometrySerde.serialize(
