@@ -232,6 +232,24 @@ public class UDFsV2 {
     return Functions.azimuth(GeometrySerde.deserGeoJson(left), GeometrySerde.deserGeoJson(right));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry"},
+      argTypes = {"Geometry"},
+      returnTypes = "Geometry")
+  public static String ST_ApproximateMedialAxis(String geometry) {
+    return GeometrySerde.serGeoJson(
+        Functions.approximateMedialAxis(GeometrySerde.deserGeoJson(geometry)));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "maxVertices"},
+      argTypes = {"Geometry", "int"},
+      returnTypes = "Geometry")
+  public static String ST_ApproximateMedialAxis(String geometry, int maxVertices) {
+    return GeometrySerde.serGeoJson(
+        Functions.approximateMedialAxis(GeometrySerde.deserGeoJson(geometry), maxVertices));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry"},
       argTypes = {"Geometry"},
@@ -501,6 +519,15 @@ public class UDFsV2 {
     return GeometrySerde.serGeoJson(Functions.envelope(GeometrySerde.deserGeoJson(geometry)));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry"},
+      argTypes = {"Geometry"},
+      returnTypes = "Geometry")
+  public static String ST_OrientedEnvelope(String geometry) {
+    return GeometrySerde.serGeoJson(
+        Functions.orientedEnvelope(GeometrySerde.deserGeoJson(geometry)));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry", "uniformDelta"},
       argTypes = {"Geometry", "double"},
@@ -1228,6 +1255,24 @@ public class UDFsV2 {
     return GeometrySerde.serGeoJson(Functions.startPoint(GeometrySerde.deserGeoJson(geometry)));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry"},
+      argTypes = {"Geometry"},
+      returnTypes = "Geometry")
+  public static String ST_StraightSkeleton(String geometry) {
+    return GeometrySerde.serGeoJson(
+        Functions.straightSkeleton(GeometrySerde.deserGeoJson(geometry)));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "maxVertices"},
+      argTypes = {"Geometry", "int"},
+      returnTypes = "Geometry")
+  public static String ST_StraightSkeleton(String geometry, int maxVertices) {
+    return GeometrySerde.serGeoJson(
+        Functions.straightSkeleton(GeometrySerde.deserGeoJson(geometry), maxVertices));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"input", "reference", "tolerance"},
       argTypes = {"Geometry", "Geometry", "double"},
