@@ -19,19 +19,18 @@
 package org.apache.sedona.core.joinJudgement;
 
 import java.io.Serializable;
-import java.util.*;
+import java.util.Collections;
+import java.util.Iterator;
+import java.util.List;
 import org.apache.commons.lang3.tuple.Pair;
 import org.apache.sedona.core.enums.DistanceMetric;
 import org.apache.sedona.core.knnJudgement.EuclideanItemDistance;
 import org.apache.sedona.core.knnJudgement.HaversineItemDistance;
 import org.apache.sedona.core.knnJudgement.SpheroidDistance;
-import org.apache.sedona.core.wrapper.UniqueGeometry;
 import org.apache.spark.api.java.function.FlatMapFunction2;
 import org.apache.spark.broadcast.Broadcast;
 import org.apache.spark.util.LongAccumulator;
-import org.locationtech.jts.geom.Envelope;
 import org.locationtech.jts.geom.Geometry;
-import org.locationtech.jts.index.SpatialIndex;
 import org.locationtech.jts.index.strtree.GeometryItemDistance;
 import org.locationtech.jts.index.strtree.ItemDistance;
 import org.locationtech.jts.index.strtree.STRtree;
@@ -45,19 +44,17 @@ import org.locationtech.jts.index.strtree.STRtree;
  */
 public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
     extends JudgementBase<T, U>
-    implements FlatMapFunction2<Iterator<T>, Iterator<SpatialIndex>, Pair<U, T>>, Serializable {
+    implements FlatMapFunction2<Iterator<T>, Iterator<U>, Pair<T, U>>, Serializable {
   private final int k;
-  private final Double searchRadius;
   private final DistanceMetric distanceMetric;
   private final boolean includeTies;
-  private final Broadcast<List> broadcastQueryObjects;
+  private final Broadcast<List<T>> broadcastQueryObjects;
   private final Broadcast<STRtree> broadcastObjectsTreeIndex;
 
   /**
    * Constructor for the KnnJoinIndexJudgement class.
    *
    * @param k the number of nearest neighbors to find
-   * @param searchRadius
    * @param distanceMetric the distance metric to use
    * @param broadcastQueryObjects the broadcast geometries on queries
    * @param broadcastObjectsTreeIndex the broadcast spatial index on objects
@@ -68,10 +65,9 @@ public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
    */
   public KnnJoinIndexJudgement(
       int k,
-      Double searchRadius,
       DistanceMetric distanceMetric,
       boolean includeTies,
-      Broadcast<List> broadcastQueryObjects,
+      Broadcast<List<T>> broadcastQueryObjects,
       Broadcast<STRtree> broadcastObjectsTreeIndex,
       LongAccumulator buildCount,
       LongAccumulator streamCount,
@@ -79,7 +75,6 @@ public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
       LongAccumulator candidateCount) {
     super(null, buildCount, streamCount, resultCount, candidateCount);
     this.k = k;
-    this.searchRadius = searchRadius;
     this.distanceMetric = distanceMetric;
     this.includeTies = includeTies;
     this.broadcastQueryObjects = broadcastQueryObjects;
@@ -91,15 +86,15 @@ public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
    * and uses the spatial index to find the k nearest neighbors for each geometry. The method
    * returns an iterator over the join results.
    *
-   * @param streamShapes iterator over the geometries in the stream side
-   * @param treeIndexes iterator over the spatial indexes
+   * @param queryShapes iterator over the geometries in the query side
+   * @param objectShapes iterator over the geometries in the object side
    * @return an iterator over the join results
    * @throws Exception if the spatial index is not of type STRtree
    */
   @Override
-  public Iterator<Pair<U, T>> call(Iterator<T> streamShapes, Iterator<SpatialIndex> treeIndexes)
+  public Iterator<Pair<T, U>> call(Iterator<T> queryShapes, Iterator<U> objectShapes)
       throws Exception {
-    if (!treeIndexes.hasNext() || (streamShapes != null && !streamShapes.hasNext())) {
+    if (!objectShapes.hasNext() || (queryShapes != null && !queryShapes.hasNext())) {
       buildCount.add(0);
       streamCount.add(0);
       resultCount.add(0);
@@ -107,91 +102,64 @@ public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
       return Collections.emptyIterator();
     }
 
-    STRtree strTree;
-    if (broadcastObjectsTreeIndex != null) {
-      // get the broadcast spatial index on objects side if available
-      strTree = broadcastObjectsTreeIndex.getValue();
-    } else {
-      // get the spatial index from the iterator
-      SpatialIndex treeIndex = treeIndexes.next();
-      if (!(treeIndex instanceof STRtree)) {
-        throw new Exception(
-            "[KnnJoinIndexJudgement][Call] Only STRtree index supports KNN search.");
-      }
-      strTree = (STRtree) treeIndex;
-    }
-
-    // TODO: For future improvement, instead of using a list to store the results,
-    // we can use lazy evaluation to avoid storing all the results in memory.
-    List<Pair<U, T>> result = new ArrayList<>();
-
-    List queryItems;
-    if (broadcastQueryObjects != null) {
-      // get the broadcast spatial index on queries side if available
-      queryItems = broadcastQueryObjects.getValue();
-      for (Object item : queryItems) {
-        T queryGeom;
-        if (item instanceof UniqueGeometry) {
-          queryGeom = (T) ((UniqueGeometry) item).getOriginalGeometry();
-        } else {
-          queryGeom = (T) item;
-        }
-        streamCount.add(1);
-
-        Object[] localK =
-            strTree.nearestNeighbour(
-                queryGeom.getEnvelopeInternal(), queryGeom, getItemDistance(), k);
-        if (includeTies) {
-          localK = getUpdatedLocalKWithTies(queryGeom, localK, strTree);
-        }
-        if (searchRadius != null) {
-          localK = getInSearchRadius(localK, queryGeom);
-        }
-
-        for (Object obj : localK) {
-          T candidate = (T) obj;
-          Pair<U, T> pair = Pair.of((U) item, candidate);
-          result.add(pair);
-          resultCount.add(1);
-        }
-      }
-      return result.iterator();
-    } else {
-      while (streamShapes.hasNext()) {
-        T streamShape = streamShapes.next();
-        streamCount.add(1);
-
-        Object[] localK =
-            strTree.nearestNeighbour(
-                streamShape.getEnvelopeInternal(), streamShape, getItemDistance(), k);
-        if (includeTies) {
-          localK = getUpdatedLocalKWithTies(streamShape, localK, strTree);
-        }
-        if (searchRadius != null) {
-          localK = getInSearchRadius(localK, streamShape);
-        }
-
-        for (Object obj : localK) {
-          T candidate = (T) obj;
-          Pair<U, T> pair = Pair.of((U) streamShape, candidate);
-          result.add(pair);
-          resultCount.add(1);
-        }
-      }
-      return result.iterator();
-    }
+    STRtree strTree = buildSTRtree(objectShapes);
+    return new InMemoryKNNJoinIterator<>(
+        queryShapes, strTree, k, distanceMetric, includeTies, streamCount, resultCount);
   }
 
-  private Object[] getInSearchRadius(Object[] localK, T queryGeom) {
-    localK =
-        Arrays.stream(localK)
-            .filter(
-                candidate -> {
-                  Geometry candidateGeom = (Geometry) candidate;
-                  return distanceByMetric(queryGeom, candidateGeom, distanceMetric) <= searchRadius;
-                })
-            .toArray();
-    return localK;
+  /**
+   * This method performs the KNN join operation using the broadcast spatial index built using all
+   * geometries in the object side.
+   *
+   * @param queryShapes iterator over the geometries in the query side
+   * @return an iterator over the join results
+   */
+  public Iterator<Pair<T, U>> callUsingBroadcastObjectIndex(Iterator<T> queryShapes) {
+    if (!queryShapes.hasNext()) {
+      buildCount.add(0);
+      streamCount.add(0);
+      resultCount.add(0);
+      candidateCount.add(0);
+      return Collections.emptyIterator();
+    }
+
+    // There's no need to use external spatial index, since the object side is small enough to be
+    // broadcasted, the STRtree built from the broadcasted object should be able to fit into memory.
+    STRtree strTree = broadcastObjectsTreeIndex.getValue();
+    return new InMemoryKNNJoinIterator<>(
+        queryShapes, strTree, k, distanceMetric, includeTies, streamCount, resultCount);
+  }
+
+  /**
+   * This method performs the KNN join operation using the broadcast query geometries.
+   *
+   * @param objectShapes iterator over the geometries in the object side
+   * @return an iterator over the join results
+   */
+  public Iterator<Pair<T, U>> callUsingBroadcastQueryList(Iterator<U> objectShapes) {
+    if (!objectShapes.hasNext()) {
+      buildCount.add(0);
+      streamCount.add(0);
+      resultCount.add(0);
+      candidateCount.add(0);
+      return Collections.emptyIterator();
+    }
+
+    List<T> queryItems = broadcastQueryObjects.getValue();
+    STRtree strTree = buildSTRtree(objectShapes);
+    return new InMemoryKNNJoinIterator<>(
+        queryItems.iterator(), strTree, k, distanceMetric, includeTies, streamCount, resultCount);
+  }
+
+  private STRtree buildSTRtree(Iterator<U> objectShapes) {
+    STRtree strTree = new STRtree();
+    while (objectShapes.hasNext()) {
+      U spatialObject = objectShapes.next();
+      strTree.insert(spatialObject.getEnvelopeInternal(), spatialObject);
+      buildCount.add(1);
+    }
+    strTree.build();
+    return strTree;
   }
 
   /**
@@ -219,12 +187,6 @@ public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
     }
   }
 
-  private ItemDistance getItemDistance() {
-    ItemDistance itemDistance;
-    itemDistance = getItemDistanceByMetric(distanceMetric);
-    return itemDistance;
-  }
-
   /**
    * This method returns the ItemDistance object based on the specified distance metric.
    *
@@ -250,38 +212,6 @@ public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
     return itemDistance;
   }
 
-  private Object[] getUpdatedLocalKWithTies(T streamShape, Object[] localK, STRtree strTree) {
-    Envelope searchEnvelope = streamShape.getEnvelopeInternal();
-    // get the maximum distance from the k nearest neighbors
-    double maxDistance = 0.0;
-    LinkedHashSet<T> uniqueCandidates = new LinkedHashSet<>();
-    for (Object obj : localK) {
-      T candidate = (T) obj;
-      uniqueCandidates.add(candidate);
-      double distance = streamShape.distance(candidate);
-      if (distance > maxDistance) {
-        maxDistance = distance;
-      }
-    }
-    searchEnvelope.expandBy(maxDistance);
-    List<T> candidates = strTree.query(searchEnvelope);
-    if (!candidates.isEmpty()) {
-      // update localK with all candidates that are within the maxDistance
-      List<Object> tiedResults = new ArrayList<>();
-      // add all localK
-      Collections.addAll(tiedResults, localK);
-
-      for (T candidate : candidates) {
-        double distance = streamShape.distance(candidate);
-        if (distance == maxDistance && !uniqueCandidates.contains(candidate)) {
-          tiedResults.add(candidate);
-        }
-      }
-      localK = tiedResults.toArray();
-    }
-    return localK;
-  }
-
   public static <U extends Geometry, T extends Geometry> double distance(
       U key, T value, DistanceMetric distanceMetric) {
     switch (distanceMetric) {
@@ -295,4 +225,10 @@ public class KnnJoinIndexJudgement<T extends Geometry, U extends Geometry>
         return new EuclideanItemDistance().distance(key, value);
     }
   }
+
+  public static ItemDistance getItemDistance(DistanceMetric distanceMetric) {
+    ItemDistance itemDistance;
+    itemDistance = getItemDistanceByMetric(distanceMetric);
+    return itemDistance;
+  }
 }
