@@ -21,7 +21,7 @@ package org.apache.sedona.viz.extension.coloringRule;
 import java.awt.Color;
 
 public class GenericColoringRule {
-  public static Integer EncodeToRGB(Double normailizedCount) {
+  public static Integer EncodeToRGB(Double normalizedCount) {
     int alpha = 150;
     Color[] colors =
         new Color[] {
@@ -34,21 +34,21 @@ public class GenericColoringRule {
           new Color(255, 85, 0, alpha),
           new Color(255, 0, 0, alpha)
         };
-    if (normailizedCount == 0) {
+    if (normalizedCount == 0) {
       return new Color(255, 255, 255, 0).getRGB();
-    } else if (normailizedCount < 5) {
+    } else if (normalizedCount < 5) {
       return colors[0].getRGB();
-    } else if (normailizedCount < 15) {
+    } else if (normalizedCount < 15) {
       return colors[1].getRGB();
-    } else if (normailizedCount < 25) {
+    } else if (normalizedCount < 25) {
       return colors[2].getRGB();
-    } else if (normailizedCount < 35) {
+    } else if (normalizedCount < 35) {
       return colors[3].getRGB();
-    } else if (normailizedCount < 45) {
+    } else if (normalizedCount < 45) {
       return colors[4].getRGB();
-    } else if (normailizedCount < 60) {
+    } else if (normalizedCount < 60) {
       return colors[5].getRGB();
-    } else if (normailizedCount < 80) {
+    } else if (normalizedCount < 80) {
       return colors[6].getRGB();
     } else {
       return colors[7].getRGB();
