@@ -18,13 +18,13 @@
  */
 package org.apache.spark.sql.sedona_sql.expressions
 
+import org.apache.sedona.common.S2Geography.{Geography, GeographySerializer}
 import org.apache.sedona.sql.utils.GeometrySerializer
 import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.expressions.Expression
 import org.apache.spark.sql.catalyst.util.ArrayData
 import org.apache.spark.unsafe.types.UTF8String
 import org.locationtech.jts.geom.{Geometry, GeometryFactory, Point}
-import org.apache.sedona.common.geometryObjects.Geography
 
 object implicits {
 
@@ -67,7 +67,25 @@ object implicits {
           serdeAware.evalWithoutSerialization(input).asInstanceOf[Geography]
         case _ =>
           inputExpression.eval(input).asInstanceOf[Array[Byte]] match {
-            case binary: Array[Byte] => new Geography(GeometrySerializer.deserialize(binary))
+            case binary: Array[Byte] => GeographySerializer.deserialize(binary)
+            case _ => null
+          }
+      }
+    }
+
+    def toGeographyArray(input: InternalRow): Array[Geography] = {
+      inputExpression match {
+        case aware: SerdeAware =>
+          aware.evalWithoutSerialization(input).asInstanceOf[Array[Geography]]
+        case _ =>
+          inputExpression.eval(input).asInstanceOf[ArrayData] match {
+            case arrayData: ArrayData =>
+              val length = arrayData.numElements()
+              val geographyies = new Array[Geography](length)
+              for (i <- 0 until length) {
+                geographyies(i) = arrayData.getBinary(i).toGeography
+              }
+              geographyies
             case _ => null
           }
       }
@@ -109,6 +127,24 @@ object implicits {
       }
     }
 
+    def toGeographyList(input: InternalRow): java.util.List[Geography] = {
+      inputExpression match {
+        case aware: SerdeAware =>
+          aware.evalWithoutSerialization(input).asInstanceOf[java.util.List[Geography]]
+        case _ =>
+          inputExpression.eval(input).asInstanceOf[ArrayData] match {
+            case arrayData: ArrayData =>
+              val length = arrayData.numElements()
+              val geometries = new java.util.ArrayList[Geography]()
+              for (i <- 0 until length) {
+                geometries.add(arrayData.getBinary(i).toGeography)
+              }
+              geometries.asInstanceOf[java.util.List[Geography]]
+            case _ => null
+          }
+      }
+    }
+
     def toInt(input: InternalRow): Int = {
       inputExpression.eval(input).asInstanceOf[Int]
     }
@@ -142,6 +178,11 @@ object implicits {
         case _ => null
       }
     }
+    def toGeography: Geography =
+      arrayData match {
+        case binary: Array[Byte] => GeographySerializer.deserialize(binary)
+        case _ => null
+      }
   }
 
   implicit class GeometryEnhancer(geom: Geometry) {
@@ -157,6 +198,7 @@ object implicits {
 
   implicit class GeographyEnhancer(geog: Geography) {
 
-    def toGenericArrayData: Array[Byte] = GeometrySerializer.serialize(geog.getGeometry)
+    def toGenericArrayData: Array[Byte] = GeographySerializer.serialize(geog)
   }
+
 }
