@@ -29,7 +29,7 @@ import org.apache.spark.sql.sedona_sql.expressions.raster.implicits.RasterInputE
 import org.apache.spark.sql.sedona_sql.expressions.InferredExpression
 import org.geotools.coverage.grid.GridCoverage2D
 
-case class RS_BandNoDataValue(inputExpressions: Seq[Expression])
+private[apache] case class RS_BandNoDataValue(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterBandAccessors.getBandNoDataValue),
       inferrableFunction1(RasterBandAccessors.getBandNoDataValue)) {
@@ -38,7 +38,7 @@ case class RS_BandNoDataValue(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_Count(inputExpressions: Seq[Expression])
+private[apache] case class RS_Count(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterBandAccessors.getCount),
       inferrableFunction1(RasterBandAccessors.getCount),
@@ -48,7 +48,7 @@ case class RS_Count(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_ZonalStats(inputExpressions: Seq[Expression])
+private[apache] case class RS_ZonalStats(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction7(RasterBandAccessors.getZonalStats),
       inferrableFunction6(RasterBandAccessors.getZonalStats),
@@ -60,7 +60,7 @@ case class RS_ZonalStats(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_SummaryStats(inputExpressions: Seq[Expression])
+private[apache] case class RS_SummaryStats(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterBandAccessors.getSummaryStats),
       inferrableFunction3(RasterBandAccessors.getSummaryStats),
@@ -70,7 +70,7 @@ case class RS_SummaryStats(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_Band(inputExpressions: Seq[Expression])
+private[apache] case class RS_Band(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterBandAccessors.getBand _) {
 
   override def evalWithoutSerialization(input: InternalRow): Any = {
@@ -93,7 +93,7 @@ case class RS_Band(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_BandPixelType(inputExpressions: Seq[Expression])
+private[apache] case class RS_BandPixelType(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterBandAccessors.getBandType),
       inferrableFunction1(RasterBandAccessors.getBandType)) {
@@ -102,7 +102,7 @@ case class RS_BandPixelType(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_BandIsNoData(inputExpressions: Seq[Expression])
+private[apache] case class RS_BandIsNoData(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterBandAccessors.bandIsNoData),
       inferrableFunction1(RasterBandAccessors.bandIsNoData)) {
