@@ -108,6 +108,15 @@ object st_functions {
   def ST_Azimuth(pointA: String, pointB: String): Column =
     wrapExpression[ST_Azimuth](pointA, pointB)
 
+  def ST_ApproximateMedialAxis(geometry: Column): Column =
+    wrapExpression[ST_ApproximateMedialAxis](geometry)
+  def ST_ApproximateMedialAxis(geometry: String): Column =
+    wrapExpression[ST_ApproximateMedialAxis](geometry)
+  def ST_ApproximateMedialAxis(geometry: Column, maxVertices: Column): Column =
+    wrapExpression[ST_ApproximateMedialAxis](geometry, maxVertices)
+  def ST_ApproximateMedialAxis(geometry: String, maxVertices: Int): Column =
+    wrapExpression[ST_ApproximateMedialAxis](geometry, maxVertices)
+
   def ST_Boundary(geometry: Column): Column = wrapExpression[ST_Boundary](geometry)
   def ST_Boundary(geometry: String): Column = wrapExpression[ST_Boundary](geometry)
 
@@ -495,6 +504,11 @@ object st_functions {
   def ST_MinimumBoundingRadius(geometry: String): Column =
     wrapExpression[ST_MinimumBoundingRadius](geometry)
 
+  def ST_OrientedEnvelope(geometry: Column): Column =
+    wrapExpression[ST_OrientedEnvelope](geometry)
+  def ST_OrientedEnvelope(geometry: String): Column =
+    wrapExpression[ST_OrientedEnvelope](geometry)
+
   def ST_IsPolygonCCW(geometry: Column): Column = wrapExpression[ST_IsPolygonCCW](geometry)
   def ST_IsPolygonCCW(geometry: String): Column = wrapExpression[ST_IsPolygonCCW](geometry)
 
@@ -625,6 +639,15 @@ object st_functions {
   def ST_StartPoint(lineString: Column): Column = wrapExpression[ST_StartPoint](lineString)
   def ST_StartPoint(lineString: String): Column = wrapExpression[ST_StartPoint](lineString)
 
+  def ST_StraightSkeleton(geometry: Column): Column =
+    wrapExpression[ST_StraightSkeleton](geometry)
+  def ST_StraightSkeleton(geometry: String): Column =
+    wrapExpression[ST_StraightSkeleton](geometry)
+  def ST_StraightSkeleton(geometry: Column, maxVertices: Column): Column =
+    wrapExpression[ST_StraightSkeleton](geometry, maxVertices)
+  def ST_StraightSkeleton(geometry: String, maxVertices: Int): Column =
+    wrapExpression[ST_StraightSkeleton](geometry, maxVertices)
+
   def ST_Snap(input: Column, reference: Column, tolerance: Column): Column =
     wrapExpression[ST_Snap](input, reference, tolerance)
   def ST_Snap(input: String, reference: String, tolerance: Double): Column =
@@ -1038,4 +1061,13 @@ object st_functions {
       selfWeight,
       useSpheroid,
       attributes)
+
+  def barrier(expression: Column, args: Column*): Column = {
+    val allArgs = expression +: args
+    wrapExpression[Barrier](allArgs: _*)
+  }
+  def barrier(expression: String, args: Any*): Column = {
+    val allArgs = expression +: args
+    wrapExpression[Barrier](allArgs: _*)
+  }
 }
