@@ -209,9 +209,9 @@ case class KNNJoinExec(
     // Number of neighbors to find
     val kValue: Int = this.k.eval().asInstanceOf[Int]
     // Metric to use in the join to calculate the distance, only Euclidean and Spheroid are supported
-    val distanceMetric = if (isGeography) DistanceMetric.SPHEROID else DistanceMetric.EUCLIDEAN
+    val distanceMetric = if (isGeography) DistanceMetric.HAVERSINE else DistanceMetric.EUCLIDEAN
     val joinParams =
-      new JoinParams(true, null, IndexType.RTREE, null, kValue, distanceMetric, null)
+      new JoinParams(true, null, IndexType.RTREE, null, kValue, distanceMetric)
     joinParams
   }
 }
