@@ -19,6 +19,7 @@
 package org.apache.sedona.core.spatialOperator;
 
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
@@ -50,7 +51,9 @@ public class RangeQueryTest extends SpatialQueryTestBase {
 
   @Parameterized.Parameters(name = "RangeQueryTest-{index}: {0}")
   public static SpatialPredicate[] spatialPredicates() {
-    return SpatialPredicate.values();
+    return Arrays.stream(SpatialPredicate.values())
+        .filter(predicate -> predicate != SpatialPredicate.KNN)
+        .toArray(SpatialPredicate[]::new);
   }
 
   private final SpatialPredicate spatialPredicate;
