@@ -33,18 +33,9 @@ class StacBatchTest extends TestBaseScala {
     Source.fromResource(resourceFilePath).getLines().mkString("\n")
   }
 
-  def getAbsolutePathOfResource(resourceFilePath: String): String = {
-    val resourceUrl = getClass.getClassLoader.getResource(resourceFilePath)
-    if (resourceUrl != null) {
-      resourceUrl.getPath
-    } else {
-      throw new IllegalArgumentException(s"Resource not found: $resourceFilePath")
-    }
-  }
-
   it("collectItemLinks should collect correct item links") {
     val collectionUrl =
-      "https://earth-search.aws.element84.com/v1/collections/sentinel-2-pre-c1-l2a"
+      StacTestUtils.getFileUrlOfResource("stac/collections/sentinel-2-pre-c1-l2a.json")
     val stacCollectionJson = StacUtils.loadStacCollectionToJson(collectionUrl)
     val opts = mutable
       .Map(
@@ -85,15 +76,16 @@ class StacBatchTest extends TestBaseScala {
         |  "id": "sample-collection",
         |  "description": "A sample STAC collection",
         |  "links": [
-        |    {"rel": "item", "href": "https://storage.googleapis.com/cfo-public/vegetation/California-Vegetation-CanopyBaseHeight-2016-Summer-00010m.json"},
-        |    {"rel": "item", "href": "https://storage.googleapis.com/cfo-public/vegetation/California-Vegetation-CanopyBaseHeight-2016-Summer-00010m.json"},
-        |    {"rel": "item", "href": "https://storage.googleapis.com/cfo-public/vegetation/California-Vegetation-CanopyBaseHeight-2016-Summer-00010m.json"}
+        |    {"rel": "item", "href": "mock-item-1.json"},
+        |    {"rel": "item", "href": "mock-item-2.json"},
+        |    {"rel": "item", "href": "mock-item-3.json"}
         |  ]
         |}
       """.stripMargin
 
     val opts = mutable.Map("numPartitions" -> "2", "itemsLimitMax" -> "20").toMap
-    val collectionUrl = "https://storage.googleapis.com/cfo-public/vegetation/collection.json"
+    val collectionUrl =
+      StacTestUtils.getFileUrlOfResource("stac/collections/vegetation-collection.json")
 
     val stacBatch =
       StacBatch(
@@ -121,7 +113,8 @@ class StacBatchTest extends TestBaseScala {
       """.stripMargin
 
     val opts = mutable.Map("numPartitions" -> "2", "itemsLimitMax" -> "20").toMap
-    val collectionUrl = "https://path/to/collection.json"
+    val collectionUrl =
+      StacTestUtils.getFileUrlOfResource("stac/collections/vegetation-collection.json")
 
     val stacBatch =
       StacBatch(
@@ -142,7 +135,7 @@ class StacBatchTest extends TestBaseScala {
     val rootJsonFile = "datasource_stac/collection.json"
     val stacCollectionJson = loadJsonFromResource(rootJsonFile)
     val opts = mutable.Map("numPartitions" -> "3", "itemsLimitMax" -> "20").toMap
-    val collectionUrl = getAbsolutePathOfResource(rootJsonFile)
+    val collectionUrl = StacTestUtils.getFileUrlOfResource(rootJsonFile)
 
     val stacBatch =
       StacBatch(
