@@ -502,7 +502,7 @@ class ShapefileTests extends TestBaseScala with BeforeAndAfterAll {
         .format("shapefile")
         .load(temporaryLocation)
         .select("part", "id", "aInt", "aUnicode", "geometry")
-      val rows = shapefileDf.collect()
+      var rows = shapefileDf.collect()
       assert(rows.length == 9)
       rows.foreach { row =>
         assert(row.getAs[Geometry]("geometry").isInstanceOf[Point])
@@ -517,6 +517,18 @@ class ShapefileTests extends TestBaseScala with BeforeAndAfterAll {
           assert(row.getAs[String]("aUnicode") == s"测试$id")
         }
       }
+
+      // Using partition filters
+      rows = shapefileDf.where("part = 2").collect()
+      assert(rows.length == 4)
+      rows.foreach { row =>
+        assert(row.getAs[Geometry]("geometry").isInstanceOf[Point])
+        assert(row.getAs[Int]("part") == 2)
+        val id = row.getAs[Long]("id")
+        assert(id > 10)
+        assert(row.getAs[Long]("aInt") == id)
+        assert(row.getAs[String]("aUnicode") == s"测试$id")
+      }
     }
 
     it("read with recursiveFileLookup") {
